@@ -3,6 +3,8 @@ from os import environ
 from os.path import dirname, join
 
 import dotenv
+from dotenv.version import __version__
+from dotenv.cli import cli as dotenv_cli
 
 import sh
 
@@ -21,15 +23,32 @@ def test_get_key():
     assert success is None
 
 
+def test_set_key(dotenv_file):
+    success, key_to_set, value_to_set = dotenv.set_key(dotenv_path, 'HELLO', 'WORLD')
+    success, key_to_set, value_to_set = dotenv.set_key(dotenv_path, 'foo', 'bar')
+    dotenv.get_key(dotenv_path, 'HELLO') == 'WORLD'
+
+    success, key_to_set, value_to_set = dotenv.set_key(dotenv_path, 'HELLO', 'WORLD 2')
+    dotenv.get_key(dotenv_path, 'HELLO') == 'WORLD 2'
+    dotenv.get_key(dotenv_path, 'foo') == 'bar'
+
+
 def test_list(cli, dotenv_file):
     success, key_to_set, value_to_set = dotenv.set_key(dotenv_file, 'HELLO', 'WORLD')
-    result = cli.invoke(dotenv.cli.cli, ['--file', dotenv_file, 'list'])
+    result = cli.invoke(dotenv_cli, ['--file', dotenv_file, 'list'])
     assert result.exit_code == 0, result.output
-    assert result.output == 'HELLO="WORLD"\n'
+    assert result.output == 'HELLO=WORLD\n'
+
+
+def test_get_cli(cli, dotenv_file):
+    cli.invoke(dotenv_cli, ['--file', dotenv_file, 'set', 'HELLO', "WORLD 1"])
+    result = cli.invoke(dotenv_cli, ['--file', dotenv_file, 'get', 'HELLO'])
+    assert result.exit_code == 0, result.output
+    assert result.output == 'HELLO=WORLD 1\n'
 
 
 def test_list_wo_file(cli):
-    result = cli.invoke(dotenv.cli.cli, ['--file', 'doesnotexists', 'list'])
+    result = cli.invoke(dotenv_cli, ['--file', 'doesnotexists', 'list'])
     assert result.exit_code == 2, result.output
     assert 'Invalid value for "-f"' in result.output
 
@@ -76,12 +95,26 @@ def test_unset():
     stored_value = dotenv.get_key(dotenv_path, 'HELLO')
     assert stored_value == 'WORLD'
     success, key_to_unset = dotenv.unset_key(dotenv_path, 'HELLO')
+    assert success is True
     assert dotenv.get_key(dotenv_path, 'HELLO') is None
+    success, key_to_unset = dotenv.unset_key(dotenv_path, 'RANDOM')
+    assert success is None
     sh.rm(dotenv_path)
     success, key_to_unset = dotenv.unset_key(dotenv_path, 'HELLO')
     assert success is None
 
 
+def test_unset_cli(cli, dotenv_file):
+    success, key_to_set, value_to_set = dotenv.set_key(dotenv_file, 'TESTHELLO', 'WORLD')
+    dotenv.get_key(dotenv_file, 'TESTHELLO') == 'WORLD'
+    result = cli.invoke(dotenv_cli, ['--file', dotenv_file, 'unset', 'TESTHELLO'])
+    assert result.exit_code == 0, result.output
+    assert result.output == 'Successfully removed TESTHELLO\n'
+    dotenv.get_key(dotenv_file, 'TESTHELLO') is None
+    result = cli.invoke(dotenv_cli, ['--file', dotenv_file, 'unset', 'TESTHELLO'])
+    assert result.exit_code == 1, result.output
+
+
 def test_console_script(cli):
     TEST_COMBINATIONS = (
         # quote_mode, var_name, var_value, expected_result
@@ -117,7 +150,7 @@ def test_default_path(cli):
         sh.cd(here)
         sh.dotenv('set', 'HELLO', 'WORLD')
         output = sh.dotenv('get', 'HELLO')
-        assert output == 'HELLO="WORLD"\n'
+        assert output == 'HELLO=WORLD\n'
         sh.rm(dotenv_path)
 
 
@@ -160,3 +193,35 @@ def test_get_key_with_interpolation_of_unset_variable(cli):
         assert stored_value == 'BAR'
         del(environ['NOT_SET'])
         sh.rm(dotenv_path)
+
+
+def test_run(cli):
+    with cli.isolated_filesystem():
+        sh.touch(dotenv_path)
+        sh.cd(here)
+        dotenv.set_key(dotenv_path, 'FOO', 'BAR')
+        result = sh.dotenv('run', 'printenv', 'FOO').strip()
+        assert result == 'BAR'
+
+
+def test_run_with_other_env(cli, dotenv_file):
+    cli.invoke(dotenv_cli, ['--file', dotenv_file, 'set', 'FOO', "BAR"])
+    result = cli.invoke(dotenv_cli, ['--file', dotenv_file, 'run', 'printenv', 'FOO'])
+    assert result.output.strip() == 'BAR'
+
+
+def test_run_without_cmd(cli):
+    result = cli.invoke(dotenv_cli, ['run'])
+    assert result.exit_code != 0
+
+
+def test_run_with_invalid_cmd(cli):
+    result = cli.invoke(dotenv_cli, ['run', 'i_do_not_exist'])
+    assert result.exit_code != 0
+
+
+def test_run_with_version(cli):
+    result = cli.invoke(dotenv_cli, ['--version'])
+    print(vars(result))
+    assert result.exit_code == 0
+    assert result.output.strip().endswith(__version__)
